@@ -2,7 +2,7 @@
 Auxjad
 ======
 
-Auxjad is a library of auxiliary classes and functions for Abjad 3.1 aimed at
+Auxjad is a library of auxiliary classes and functions for Abjad 3.4 aimed at
 composers of algorithmic music. All classes and functions have a ``__doc__``
 attribute with usage instructions.
 
@@ -16,6 +16,8 @@ This library is published under the MIT License.
 from .core.CartographySelector import CartographySelector
 from .core.CrossFader import CrossFader
 from .core.Fader import Fader
+from .core.FittestMeasureMaker import FittestMeasureMaker
+from .core.GeneticAlgorithm import GeneticAlgorithm
 from .core.Hocketer import Hocketer
 from .core.LeafLooper import LeafLooper
 from .core.ListLooper import ListLooper
@@ -26,7 +28,6 @@ from .core.Shuffler import Shuffler
 from .core.TenneySelector import TenneySelector
 from .core.WindowLooper import WindowLooper
 
-from .indicators.NumericOttava import NumericOttava
 from .indicators.TimeSignature import TimeSignature
 
 from .score.ArtificialHarmonic import ArtificialHarmonic
@@ -34,23 +35,23 @@ from .score.HarmonicNote import HarmonicNote
 from .score.LeafDynMaker import LeafDynMaker
 
 from .spanners.half_piano_pedal import half_piano_pedal
-from .spanners.ottava import ottava
 from .spanners.piano_pedal import piano_pedal
 
-from .utilities.inspect import Inspection
-from .utilities.inspect import inspect
-from .utilities.mutate import Mutation
-from .utilities.mutate import mutate
+from . import get
+
+from . import mutate
 
 
 __author__ = "Gilberto Agostinho <gilbertohasnofb@gmail.com>"
-__version__ = "0.8.22"
+__version__ = "0.9.0"
 __all__ = [
     '__author__',
     '__version__',
     'CartographySelector',
     'CrossFader',
     'Fader',
+    'FittestMeasureMaker',
+    'GeneticAlgorithm',
     'Hocketer',
     'LeafLooper',
     'ListLooper',
@@ -60,16 +61,12 @@ __all__ = [
     'Shuffler',
     'TenneySelector',
     'WindowLooper',
-    'NumericOttava',
     'TimeSignature',
     'ArtificialHarmonic',
     'HarmonicNote',
     'LeafDynMaker',
     'half_piano_pedal',
-    'ottava',
     'piano_pedal',
-    'Inspection',
-    'inspect',
-    'Mutation',
+    'get',
     'mutate',
 ]
