@@ -3,7 +3,7 @@ from typing import Optional, Union
 
 import abjad
 
-from ..utilities.mutate import mutate
+from .. import mutate
 from .TenneySelector import TenneySelector
 
 
@@ -24,50 +24,59 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            \time 4/4
-            a'4
-            b'4
-            cs''4
-            fs'4
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-134lqskbb6o.png
+        ..  docs::
+
+            \new Staff
+            {
+                \time 4/4
+                a'4
+                b'4
+                cs''4
+                fs'4
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-134lqskbb6o.png
 
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            \time 4/4
-            b'4
-            b'4
-            b'4
-            fs'4
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-z66g1fy8nm8.png
+        ..  docs::
+
+            \new Staff
+            {
+                \time 4/4
+                b'4
+                b'4
+                b'4
+                fs'4
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-z66g1fy8nm8.png
 
         To get the result of the last operation, use the property
         :attr:`current_window`.
 
         >>> notes = randomiser.current_window
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            \time 4/4
-            b'4
-            b'4
-            b'4
-            fs'4
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-x0e6yduogh.png
+        ..  docs::
 
-    .. warning::
+            \new Staff
+            {
+                \time 4/4
+                b'4
+                b'4
+                b'4
+                fs'4
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-x0e6yduogh.png
+
+    ..  warning::
 
         Unlike the other classes in Auxjad, the very first call of this class
         will already process the initial container. To disable this behaviour
@@ -83,29 +92,35 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            c'4
-            d'4
-            e'4
-            f'4
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-640x6vsjwtk.png
+        ..  docs::
+
+            \new Staff
+            {
+                c'4
+                d'4
+                e'4
+                f'4
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-640x6vsjwtk.png
 
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            b'4
-            fs'4
-            gs'4
-            fs'4
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-vsjdj8gkanj.png
+        ..  docs::
+
+            \new Staff
+            {
+                b'4
+                fs'4
+                gs'4
+                fs'4
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-vsjdj8gkanj.png
 
     :func:`len()`:
         Applying the :func:`len()` function to the randomiser will return the
@@ -188,18 +203,21 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            bf'8.
-            af'4
-            r8
-            r8.
-            bf'16
-            a'8.
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-u4294ozm92.png
+        ..  docs::
+
+            \new Staff
+            {
+                bf'8.
+                af'4
+                r8
+                r8.
+                bf'16
+                a'8.
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-u4294ozm92.png
 
     Chords:
         Each note of a chord is randomised too.
@@ -213,18 +231,21 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            <fs' g' bf'>8.
-            b'4
-            r8
-            r8.
-            bf'16
-            <fs' bf'>8.
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-318eldj7tzc.png
+        ..  docs::
+
+            \new Staff
+            {
+                <fs' g' bf'>8.
+                b'4
+                r8
+                r8.
+                bf'16
+                <fs' bf'>8.
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-318eldj7tzc.png
 
         The number of notes in a chord stay the same unless there are fewer
         pitches available in :attr:`pitches`.
@@ -238,14 +259,17 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            <fs' g' af'>2
-            <fs' g' af'>2
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-cciyee49qrj.png
+        ..  docs::
+
+            \new Staff
+            {
+                <fs' g' af'>2
+                <fs' g' af'>2
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-cciyee49qrj.png
 
     :attr:`use_tenney_selector`:
         Setting :attr:`use_tenney_selector` to ``True`` will make the
@@ -263,20 +287,23 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            fs'8
-            a'8
-            fs'8
-            gs'8
-            a'8
-            b'8
-            gs'8
-            fs'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-tmxllu13pa8.png
+        ..  docs::
+
+            \new Staff
+            {
+                fs'8
+                a'8
+                fs'8
+                gs'8
+                a'8
+                b'8
+                gs'8
+                fs'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-tmxllu13pa8.png
 
     :attr:`weights`:
         Individual pitches can have different weights, defined by the
@@ -291,20 +318,23 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            b'8
-            fs'8
-            gs'8
-            gs'8
-            gs'8
-            fs'8
-            fs'8
-            a'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-zkvbzd1brgq.png
+        ..  docs::
+
+            \new Staff
+            {
+                b'8
+                fs'8
+                gs'8
+                gs'8
+                gs'8
+                fs'8
+                fs'8
+                a'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-zkvbzd1brgq.png
 
     :attr:`weights` and :attr:`use_tenney_selector`:
         Non-uniform :attr:`weights` can also be used when
@@ -319,20 +349,23 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            fs'8
-            gs'8
-            a'8
-            fs'8
-            gs'8
-            a'8
-            gs'8
-            b'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-cq1nobkjozg.png
+        ..  docs::
+
+            \new Staff
+            {
+                fs'8
+                gs'8
+                a'8
+                fs'8
+                gs'8
+                a'8
+                gs'8
+                b'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-cq1nobkjozg.png
 
     Resetting :attr:`weights`:
         Setting :attr:`weights` to ``None`` will reset it back to a uniform
@@ -346,38 +379,44 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            fs'8
-            fs'8
-            fs'8
-            fs'8
-            fs'8
-            fs'8
-            fs'8
-            fs'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-wtl5o15q5qp.png
+        ..  docs::
+
+            \new Staff
+            {
+                fs'8
+                fs'8
+                fs'8
+                fs'8
+                fs'8
+                fs'8
+                fs'8
+                fs'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-wtl5o15q5qp.png
 
         >>> randomiser.weights = None
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            fs'8
-            fs'8
-            b'8
-            gs'8
-            gs'8
-            a'8
-            fs'8
-            b'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-4bqe6cbawg6.png
+        ..  docs::
+
+            \new Staff
+            {
+                fs'8
+                fs'8
+                b'8
+                gs'8
+                gs'8
+                a'8
+                fs'8
+                b'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-4bqe6cbawg6.png
 
     Changing :attr:`pitches`:
         When using a custom :obj:`list` of :attr:`weights`, changing the
@@ -403,7 +442,7 @@ class PitchRandomiser:
         >>> randomiser.weights
         None
 
-    .. error::
+    ..  error::
 
         Note that :attr:`weights` must always have the same length as
         :attr:`pitches`, otherwise a :exc:`ValueError` exception will be
@@ -426,33 +465,36 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser.output_n(3)
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            a'4
-            ~
-            a'16
-            r8.
-            g'4
-            fs'8.
-            r16
-            g'4
-            ~
-            g'16
-            r8.
-            g'4
-            fs'8.
-            r16
-            bf'4
-            ~
-            bf'16
-            r8.
-            a'4
-            af'8.
-            r16
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-fvwaaz3vgi.png
+        ..  docs::
+
+            \new Staff
+            {
+                a'4
+                ~
+                a'16
+                r8.
+                g'4
+                fs'8.
+                r16
+                g'4
+                ~
+                g'16
+                r8.
+                g'4
+                fs'8.
+                r16
+                bf'4
+                ~
+                bf'16
+                r8.
+                a'4
+                af'8.
+                r16
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-fvwaaz3vgi.png
 
     Indicators:
         This class preserves indicators.
@@ -466,27 +508,30 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            a'4
-            \p
-            \<
-            ~
-            a'8.
-            c''16
-            \f
-            - \staccato
-            af'4
-            \pp
-            - \tenuto
-            a'8.
-            (
-            bf'16
-            )
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-2e647eng8yc.png
+        ..  docs::
+
+            \new Staff
+            {
+                a'4
+                \p
+                \<
+                ~
+                a'8.
+                c''16
+                \f
+                - \staccato
+                af'4
+                \pp
+                - \tenuto
+                a'8.
+                (
+                bf'16
+                )
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-2e647eng8yc.png
 
     Example:
         This class also preserves the time signature structure.
@@ -500,20 +545,23 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            \time 3/4
-            a'4
-            fs'2
-            \time 2/4
-            gs'8
-            gs'8
-            a'8
-            gs'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-c9t7r3thrqg.png
+        ..  docs::
+
+            \new Staff
+            {
+                \time 3/4
+                a'4
+                fs'2
+                \time 2/4
+                gs'8
+                gs'8
+                a'8
+                gs'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-c9t7r3thrqg.png
 
     :attr:`omit_time_signatures`:
         To omit time signatures altogether, set :attr:`omit_time_signatures` to
@@ -529,25 +577,28 @@ class PitchRandomiser:
         ...                                     )
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            a'4
-            fs'2
-            gs'8
-            gs'8
-            a'8
-            gs'8
-        }
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-mwruvbmgu3o.png
+        ..  docs::
+
+            \new Staff
+            {
+                a'4
+                fs'2
+                gs'8
+                gs'8
+                a'8
+                gs'8
+            }
+
+        ..  figure:: ../_images/PitchRandomiser-mwruvbmgu3o.png
 
     Using as iterator:
         The instances of this class can also be used as an iterator, which can
         then be used in a for loop. Note that unlike the method
         :meth:`output_n`, time signatures are added to each window returned by
         the randomiser. Use the function
-        |auxjad.mutate().remove_repeated_time_signatures()| to clean the output
+        |auxjad.mutate.remove_repeated_time_signatures()| to clean the output
         when using this class in this way. It is also important to note that a
         ``break`` statement is needed when using this class as an iterator. The
         reason is that pitch randomisation is a process that can happen
@@ -561,30 +612,33 @@ class PitchRandomiser:
         >>> staff = abjad.Staff()
         >>> for window in randomiser:
         ...     staff.append(window)
-        ...     if abjad.inspect(staff).duration() == abjad.Duration((9, 4)):
+        ...     if abjad.get.duration(staff) == abjad.Duration((9, 4)):
         ...         break
-        >>> auxjad.mutate(staff).remove_repeated_time_signatures()
-        >>> abjad.f(staff)
-        \new Staff
-        {
-            \time 3/4
-            a'4
-            b'4
-            gs'4
-            fs'4
-            a'4
-            b'4
-            a'4
-            gs'4
-            cs''4
-        }
+        >>> auxjad.mutate.remove_repeated_time_signatures(staff)
+        >>> abjad.show(staff)
 
-        .. figure:: ../_images/PitchRandomiser-2c9zzip8tpc.png
+        ..  docs::
 
-    .. tip::
+            \new Staff
+            {
+                \time 3/4
+                a'4
+                b'4
+                gs'4
+                fs'4
+                a'4
+                b'4
+                a'4
+                gs'4
+                cs''4
+            }
 
-        The functions |auxjad.mutate().remove_repeated_dynamics()| and
-        |auxjad.mutate().reposition_clefs()| can be used to clean the output
+        ..  figure:: ../_images/PitchRandomiser-2c9zzip8tpc.png
+
+    ..  tip::
+
+        The functions |auxjad.mutate.remove_repeated_dynamics()| and
+        |auxjad.mutate.reposition_clefs()| can be used to clean the output
         and remove repeated dynamics and unnecessary clef changes.
     """
 
@@ -666,8 +720,8 @@ class PitchRandomiser:
         dummy_container = abjad.Container()
         for _ in range(n):
             dummy_container.append(self.__call__())
-        mutate(dummy_container[:]).remove_repeated_time_signatures()
-        mutate(dummy_container[:]).remove_repeated_dynamics()
+        mutate.remove_repeated_time_signatures(dummy_container[:])
+        mutate.remove_repeated_dynamics(dummy_container[:])
         output = dummy_container[:]
         dummy_container[:] = []
         return output
@@ -683,7 +737,7 @@ class PitchRandomiser:
 
     def _rewrite_pitches(self) -> None:
         r'Rewrites the pitches of the current window.'
-        dummy_container = abjad.mutate(self._contents).copy()
+        dummy_container = abjad.mutate.copy(self._contents)
         logical_ties = abjad.select(dummy_container).logical_ties()
         for logical_tie in logical_ties:
             if isinstance(logical_tie[0], abjad.Note):
@@ -722,7 +776,7 @@ class PitchRandomiser:
     def _remove_all_time_signatures(container) -> None:
         r'Removes all time signatures of an |abjad.Container|.'
         for leaf in abjad.select(container).leaves():
-            if abjad.inspect(leaf).effective(abjad.TimeSignature):
+            if abjad.get.effective(leaf, abjad.TimeSignature):
                 abjad.detach(abjad.TimeSignature, leaf)
 
     ### PUBLIC PROPERTIES ###
@@ -730,7 +784,7 @@ class PitchRandomiser:
     @property
     def contents(self) -> abjad.Container:
         r'The |abjad.Container| to be shuffled.'
-        return abjad.mutate(self._contents).copy()
+        return abjad.mutate.copy(self._contents)
 
     @contents.setter
     def contents(self,
@@ -742,12 +796,12 @@ class PitchRandomiser:
         if not abjad.select(contents).leaves().are_contiguous_logical_voice():
             raise ValueError("'contents' must be contiguous logical voice")
         if isinstance(contents, abjad.Score):
-            self._contents = abjad.mutate(contents[0]).copy()
+            self._contents = abjad.mutate.copy(contents[0])
         elif isinstance(contents, abjad.Tuplet):
-            self._contents = abjad.Container([abjad.mutate(contents).copy()])
+            self._contents = abjad.Container([abjad.mutate.copy(contents)])
         else:
-            self._contents = abjad.mutate(contents).copy()
-        dummy_container = abjad.mutate(contents).copy()
+            self._contents = abjad.mutate.copy(contents)
+        dummy_container = abjad.mutate.copy(contents)
         self._current_window = dummy_container[:]
         dummy_container[:] = []
         self._is_first_window = True
@@ -848,7 +902,7 @@ class PitchRandomiser:
     @property
     def current_window(self) -> abjad.Selection:
         r'Read-only property, returns the result of the last operation.'
-        current_window = abjad.mutate(self._current_window).copy()
+        current_window = abjad.mutate.copy(self._current_window)
         if self._omit_time_signatures:
             self._remove_all_time_signatures(current_window)
         return current_window
