@@ -9,7 +9,7 @@ import auxjad
 def test_LeafLooper_01():
     container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
     looper = auxjad.LeafLooper(container, window_size=3)
-    assert format(looper) == abjad.String.normalize(
+    assert abjad.lilypond(looper) == abjad.String.normalize(
         r"""
         {
             c'4
@@ -23,7 +23,7 @@ def test_LeafLooper_01():
         """)
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -35,7 +35,7 @@ def test_LeafLooper_01():
         """)
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -51,7 +51,7 @@ def test_LeafLooper_01():
         """)
     notes = looper.current_window
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -76,6 +76,7 @@ def test_LeafLooper_02():
                                repetition_chance=0.25,
                                forward_bias=0.2,
                                head_position=0,
+                               end_with_max_n_leaves=True,
                                omit_time_signatures=False,
                                process_on_first_call=True,
                                )
@@ -85,6 +86,7 @@ def test_LeafLooper_02():
     assert looper.repetition_chance == 0.25
     assert looper.forward_bias == 0.2
     assert looper.head_position == 0
+    assert looper.end_with_max_n_leaves
     assert not looper.omit_time_signatures
     assert looper.process_on_first_call
     looper.window_size = 2
@@ -93,6 +95,7 @@ def test_LeafLooper_02():
     looper.repetition_chance = 0.1
     looper.forward_bias = 0.8
     looper.head_position = 2
+    looper.end_with_max_n_leaves = False
     looper.omit_time_signatures = True
     looper.process_on_first_call = False
     assert looper.window_size == 2
@@ -101,6 +104,7 @@ def test_LeafLooper_02():
     assert looper.repetition_chance == 0.1
     assert looper.forward_bias == 0.8
     assert looper.head_position == 2
+    assert not looper.end_with_max_n_leaves
     assert looper.omit_time_signatures
     assert not looper.process_on_first_call
 
@@ -128,7 +132,7 @@ def test_LeafLooper_05():
     looper = auxjad.LeafLooper(container, window_size=2)
     notes = looper.output_all()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -150,7 +154,7 @@ def test_LeafLooper_06():
     looper = auxjad.LeafLooper(container, window_size=3)
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -165,7 +169,7 @@ def test_LeafLooper_06():
     looper.window_size = 4
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -186,7 +190,7 @@ def test_LeafLooper_07():
                                )
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -205,7 +209,7 @@ def test_LeafLooper_08():
     looper = auxjad.LeafLooper(container, window_size=2)
     notes = looper.output_all()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -216,16 +220,19 @@ def test_LeafLooper_08():
             \time 7/24
             d'8
             \tweak edge-height #'(0.7 . 0)
-            \times 2/3 {
+            \times 2/3
+            {
                 a4
             }
-            \times 2/3 {
+            \times 2/3
+            {
                 \time 2/4
                 a4
                 g2
             }
             \tweak edge-height #'(0.7 . 0)
-            \times 2/3 {
+            \times 2/3
+            {
                 #(ly:expect-warning "strange time signature found")
                 \time 2/6
                 g2
@@ -239,7 +246,7 @@ def test_LeafLooper_09():
     looper = auxjad.LeafLooper(container, window_size=2)
     notes = looper.__next__()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -250,7 +257,7 @@ def test_LeafLooper_09():
         """)
     notes = looper.__next__()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -261,7 +268,7 @@ def test_LeafLooper_09():
         """)
     notes = looper.__next__()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -281,7 +288,7 @@ def test_LeafLooper_10():
                                )
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -358,7 +365,7 @@ def test_LeafLooper_12():
                                )
     notes = looper.output_all(tie_identical_pitches=True)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -407,7 +414,7 @@ def test_LeafLooper_13():
     looper = auxjad.LeafLooper(container, window_size=2)
     notes = looper.output_n(2)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -425,7 +432,7 @@ def test_LeafLooper_14():
     looper = auxjad.LeafLooper(container, window_size=2)
     notes = looper.output_n(2, tie_identical_pitches=True)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -455,7 +462,7 @@ def test_LeafLooper_16():
                                )
     notes = looper.output_all()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -479,7 +486,7 @@ def test_LeafLooper_17():
                                )
     notes = looper.output_all()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -498,7 +505,7 @@ def test_LeafLooper_18():
                                )
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -519,7 +526,7 @@ def test_LeafLooper_19():
                                )
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -531,7 +538,7 @@ def test_LeafLooper_19():
         """)
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -544,7 +551,7 @@ def test_LeafLooper_19():
     looper.contents = abjad.Container(r"cs'''4 ds'''4 es'''4 fs'''4")
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -557,7 +564,7 @@ def test_LeafLooper_19():
     looper.head_position = 0
     notes = looper()
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -579,7 +586,7 @@ def test_LeafLooper_20():
                                )
     notes = looper.output_n(5)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -612,7 +619,7 @@ def test_LeafLooper_21():
                                )
     notes = looper.output_n(4)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -637,7 +644,7 @@ def test_LeafLooper_22():
     staff = abjad.Staff()
     for window in looper:
         staff.append(window)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -654,8 +661,8 @@ def test_LeafLooper_22():
             f'2
         }
         """)
-    auxjad.mutate(staff[:]).remove_repeated_time_signatures()
-    assert format(staff) == abjad.String.normalize(
+    auxjad.mutate.remove_repeated_time_signatures(staff[:])
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -719,7 +726,7 @@ def test_LeafLooper_24():
                                )
     notes = looper.output_n(5)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -776,7 +783,7 @@ def test_LeafLooper_25():
                                )
     notes = looper.output_n(3)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -804,7 +811,7 @@ def test_LeafLooper_25():
                                )
     notes = looper.output_n(3)
     staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -822,3 +829,50 @@ def test_LeafLooper_25():
             g'16
         }
         """)
+
+
+def test_LeafLooper_26():
+    container = abjad.Container(r"c'4 d'4. e'4 f'8")
+    looper = auxjad.LeafLooper(container, window_size=3)
+    notes = looper.output_all()
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 7/8
+            c'4
+            d'4.
+            e'4
+            \time 3/4
+            d'4.
+            e'4
+            f'8
+            \time 3/8
+            e'4
+            f'8
+            \time 1/8
+            f'8
+        }
+        """)
+    container = abjad.Container(r"c'4 d'4. e'4 f'8")
+    looper = auxjad.LeafLooper(container,
+                               window_size=3,
+                               end_with_max_n_leaves=True,
+                               )
+    notes = looper.output_all()
+    staff = abjad.Staff(notes)
+    assert abjad.lilypond(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 7/8
+            c'4
+            d'4.
+            e'4
+            \time 3/4
+            d'4.
+            e'4
+            f'8
+        }
+        """)
