@@ -15,7 +15,7 @@ def test_example_of_usage_05():
         abjad.Chord([2, 8, 9], (1, 8)),
         auxjad.ArtificialHarmonic(r"<d' a'>8", is_parenthesized=True),
     ])
-    abjad.mutate(container[:]).respell_accidentals()
+    abjad.mutate.respell_accidentals(container[:])
     shuffler = auxjad.Shuffler(container)
     staff = abjad.Staff()
     notes = shuffler.shuffle_n(4)
@@ -24,23 +24,23 @@ def test_example_of_usage_05():
     fader = auxjad.Fader(container, fader_type='out')
     notes = fader.output_all()
     staff.append(notes)
-    abjad.mutate(staff[:]).prettify_rewrite_meter(abjad.Meter((4, 4)))
-    abjad.mutate(staff[:]).remove_repeated_time_signatures()
-    assert format(staff) == abjad.String.normalize(
+    abjad.mutate.prettify_rewrite_meter(staff[:], abjad.Meter((4, 4)))
+    abjad.mutate.remove_repeated_time_signatures(staff[:])
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
             \time 4/4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -63,14 +63,14 @@ def test_example_of_usage_05():
             r4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -104,14 +104,14 @@ def test_example_of_usage_05():
             <d' gs' a'>16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
             >8
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
@@ -123,14 +123,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -155,14 +155,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -187,14 +187,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -210,14 +210,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -233,14 +233,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -256,14 +256,14 @@ def test_example_of_usage_05():
             >4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -273,14 +273,14 @@ def test_example_of_usage_05():
             r4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
             >16
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 d'
                 \tweak style #'harmonic
                 a'
@@ -290,7 +290,7 @@ def test_example_of_usage_05():
             r4
             <
                 \parenthesize
-                \tweak ParenthesesItem.font-size #-4
+                \tweak ParenthesesItem.font-size -4
                 g
                 \tweak style #'harmonic
                 c'
